@@ -114,7 +114,15 @@ modelLookup <- function(model = NULL)
                            "enet", "enet",
                            "lasso",
                            "sddaLDA",
-                           "sddaQDA"
+                           "sddaQDA",
+                           "J48",
+                           "M5Rules",
+                           "LMT",
+                           "JRip",
+                           "lmStepAIC",
+                           "slda",
+                           "superpc",
+                           "superpc"
                            ),
                          parameter = c(
                            "parameter",      
@@ -163,7 +171,14 @@ modelLookup <- function(model = NULL)
                            "fraction","lambda", 
                            "fraction",
                            "parameter",
-                           "parameter"
+                           "parameter",
+                           "C",
+                           "pruned",
+                           "iter",
+                           "NumOpt",
+                           "parameter",
+                           "parameter",
+                           "threshold", "n.components"
                            ),
                          label = I(c(
                            "none",      
@@ -212,8 +227,14 @@ modelLookup <- function(model = NULL)
                            "Fraction of Full Solution","Weight Decay",
                            "Fraction of Full Solution",
                            "none",
-                           "none"
-                           
+                           "none",
+                           "Confidence Threshold",
+                           "Pruned",
+                           "# Iteratons",
+                           "# Optimizations",
+                           "none",
+                           "none",
+                           "Threshold", "#Components"
                            )),
                          seq = c(
                            FALSE,
@@ -262,7 +283,14 @@ modelLookup <- function(model = NULL)
                            TRUE,    FALSE,
                            TRUE,
                            FALSE,              # sdda
-                           FALSE
+                           FALSE,
+                           FALSE,
+                           FALSE,
+                           FALSE,
+                           FALSE,
+                           FALSE,
+                           FALSE,
+                           TRUE,    TRUE       # superpc
                            ),
                          forReg = c(
                            TRUE,
@@ -311,8 +339,14 @@ modelLookup <- function(model = NULL)
                            TRUE,    TRUE,
                            TRUE,
                            FALSE,
-                           FALSE
-                           
+                           FALSE,
+                           FALSE,
+                           TRUE,
+                           FALSE,
+                           FALSE,
+                           TRUE,
+                           FALSE,
+                           TRUE,    TRUE       # superpc
                            ),               
                          forClass =          
                          c(
@@ -362,8 +396,14 @@ modelLookup <- function(model = NULL)
                            FALSE,   FALSE,
                            FALSE,
                            TRUE,
-                           TRUE
-                           
+                           TRUE,
+                           TRUE,
+                           FALSE,
+                           TRUE,
+                           TRUE,
+                           FALSE,
+                           TRUE,
+                           FALSE,    FALSE
                            ),
                          probModel = c(
                            TRUE,             #   bagged trees
@@ -412,7 +452,15 @@ modelLookup <- function(model = NULL)
                            FALSE, FALSE,     #   enet (2)
                            FALSE,            #   lasso (1)
                            TRUE,             #   sdda for lda (1)
-                           TRUE              #   sdda for qda (1)
+                           TRUE,             #   sdda for qda (1)
+                           TRUE,             #   J48 (1)
+                           FALSE,            #   M5Rules(1)
+                           TRUE,             #   LMT(1)
+                           TRUE,             #   JRip(1)
+                           FALSE,            #   stepAIC(0)
+                           TRUE,             #   slda(0)
+                           FALSE, FALSE      #   superpc(2)
+
                            ),
                          stringsAsFactors  = FALSE               
                          )         
@@ -607,7 +655,14 @@ tuneScheme <- function(model, grid, useOOB = FALSE)
                grid <- grid[order(grid$.fraction, decreasing = TRUE),, drop = FALSE]
                loop <- grid[1,,drop = FALSE]
                seqParam <- list(grid[-1,,drop = FALSE])
-             }     
+             },
+             superpc =
+             {
+               largest <- which(grid$.n.components == max(grid$.n.components) &
+                                grid$.threshold == max(grid$.threshold))
+               loop <- grid[largest,, drop = FALSE]
+               seqParam <- list(grid[-largest,, drop = FALSE])
+             }
              )
       out <- list(scheme = "seq", loop = loop, seqParam = seqParam, model = modelInfo, constant = constant, vary = vary)
     } else out <- list(scheme = "basic", loop = grid, seqParam = NULL, model = modelInfo, constant = names(grid), vary = NULL)
@@ -632,11 +687,18 @@ decoerce <- function(x, grid, dot = FALSE)
   x
 }  
 
-foo <- function(x) postResample(x[,"pred"], x[,"obs"])
+## todo: make avaible to outside
+defaultSummary <- function(data, lev = NULL, model = NULL) postResample(data[,"pred"], data[,"obs"])
 
-# this function takes the raw perdictions per parameter combination 
-# and creates the resampe statistics for each combination  
-poolByResample <- function(x, grid, func)
+## This function takes the raw predictions per parameter combination 
+## and creates the resampe statistics for each combination
+
+poolByResample <- function(x,                ## The obs and pred outcomes
+                           grid,             ## The grid of tuning parameters
+                           func,             ## The summary function
+                           perfNames = NULL, ## Names of the computed metrics
+                           lev,              ## Class levels (NULL if reg)
+                           modelName)        ## The model name ("lm", "rf" etc)
 {
   k <- nrow(grid)
   for(i in 1:k)
@@ -645,8 +707,26 @@ poolByResample <- function(x, grid, func)
       subX <- merge(subGrid, x)
       if(nrow(subX) > 0)
         {
-          tmp <- by(subX, list(group = subX$group), foo)
+          tmp <- by(subX,
+                    list(group = subX$group),
+                    func,
+                    lev = lev,
+                    model = modelName)
+          
+          ## Convert the results from a "by" object to something
+          ## that we can use (a matrix). If the summary
+          ## function has one output, this will convert it to an
+          ## 1xB matrix (B = #resamples). 
+          
           resultsPerGroup <- t(sapply(tmp, function(u)u))
+
+          ## We always want an BxM matrix (M = #metrics).
+          if(length(perfNames) == 1)
+            {
+              resultsPerGroup <- t(resultsPerGroup)
+              colnames(resultsPerGroup) <- perfNames
+            }
+          
           resultsPerGroup <- merge(subGrid, resultsPerGroup)
           
           out <- if(!exists("out")) resultsPerGroup else rbind(out, resultsPerGroup)
@@ -655,7 +735,7 @@ poolByResample <- function(x, grid, func)
   out
 }
 
-summarize <- function(x, grid, func)
+summarize <- function(x, grid)
 {
   k <- nrow(grid)
   out <- NULL
@@ -724,7 +804,7 @@ modelWrapperBasic <- function(ind, x)
   outBagData$.outcome <- NULL
   
   pred <- predictionFunction(x$method, tmpModelFit, outBagData)
-  # to start computing auc ROC, we might want to return a list with
+  # todo: To start computing auc ROC, we might want to return a list with
   # probs and preds (where appropriate)
   pred
 }
@@ -828,25 +908,27 @@ iterPrint <- function(x, iter)
   cat("\n")
 }
 
-getClassLevels <- function(x)
+## make this object oriented
+getClassLevels <- function(x) 
   {
-    if(x$method %in% c("svmradial", "svmpoly",
-                       "svmRadial", "svmPoly",
-                       "rvmRadial", "rvmPoly",
-                       "gaussprRadial", "gaussprPoly",
-                       "ctree", "ctree2", "cforest"))
+    if(tolower(x$method) %in% tolower(c("svmRadial", "svmPoly",
+                                        "rvmRadial", "rvmPoly",
+                                        "lssvmRadial", "lssvmPoly",
+                                        "gaussprRadial", "gaussprPoly",
+                                        "ctree", "ctree2", "cforest")))
+       
       {
-        obsLevels <- switch(x$method,
+        obsLevels <- switch(tolower(x$method),
                             svmradial =, svmpoly =,
-                            svmRadial =, svmPoly =,
-                            rvmRadial =, rvmPoly =,
-                            gaussprRadial =, gaussprPoly =
+                            rvmradial =, rvmpoly =,
+                            lssvmradial =, lssvmpoly =, 
+                            gaussprpadial =, gaussprpoly =
                             {
                               library(kernlab)
                               lev(x$finalModel)
                             },
                             
-                            ctree =, cforest =
+                            ctree =, ctree2 =, cforest =
                             {
                               library(party)
                               levels(x$finalModel@data@get("response")[,1])
@@ -857,3 +939,5 @@ getClassLevels <- function(x)
     obsLevels
   }
 
+## todo: do we need to add the other kernlab models to the function above?
+## there is an error in test cases for predict.train
