@@ -7,6 +7,7 @@ train.default <- function(x, y,
                           method = "rf", 
                           ..., 
                           metric = ifelse(is.factor(y), "Accuracy", "RMSE"),
+                          maximize = ifelse(metric == "RMSE", FALSE, TRUE),
                           trControl = trainControl(),
                           tuneGrid = NULL, 
                           tuneLength = 3)
@@ -20,18 +21,18 @@ train.default <- function(x, y,
   if(modelType == "Classification")
     {     
       if(!any(modelInfo$forClass)) stop("wrong model type for classification")
-      # we should get and save the class labels to ensure that predictions are coerced      
-      # to factors that have the same levels as the original data. This is especially 
-      # important with multiclass systems where one or more classes have low sample sizes
-      # relative to the others
+      ## We should get and save the class labels to ensure that predictions are coerced      
+      ## to factors that have the same levels as the original data. This is especially 
+      ## important with multiclass systems where one or more classes have low sample sizes
+      ## relative to the others
       classLevels <- levels(y)
       if(length(classLevels) > 2 & (method %in% c("gbm", "glmboost", "ada", "gamboost", "blackboost")))
         stop("This model is only implimented for two class problems")
-      if(!(metric %in% c("Accuracy", "Kappa"))) 
+      if(metric %in% c("RMSE", "Rsquared")) 
         stop(paste("Metric", metric, "not applicable for classification models"))
     } else {
       if(!any(modelInfo$forReg)) stop("wrong model type for regression")
-      if(!(metric %in% c("RMSE", "Rsquared"))) 
+      if(metric %in% c("Accuracy", "Kappa")) 
         stop(paste("Metric", metric, "not applicable for regression models"))         
       classLevels <- NA
     }
@@ -43,15 +44,15 @@ train.default <- function(x, y,
                                                          tolower(trControl$method),
                                                          oob = NULL,
                                                          cv = createFolds(y, trControl$number, returnTrain = TRUE),
-                                                         loocv = createFolds(y, length(y), returnTrain = TRUE),      
+                                                         loocv = createFolds(y, length(y), returnTrain = TRUE),
                                                          boot = createResample(y, trControl$number),
                                                          test = createDataPartition(y, 1, trControl$p),
                                                          lgocv = createDataPartition(y, trControl$number, trControl$p))
   
-  # combine the features and classes into one df, as needed by ipred.
+  ## Combine the features and classes into one df, as needed by ipred.
   trainData <- as.data.frame(x)
 
-  #check mode for some models
+  ## Check mode for some models
   if(!(method %in% c("rf", "rpart", "gbm", "treebag", "nb")))
     {
       isFactor <- lapply(trainData, is.factor)
@@ -60,38 +61,59 @@ train.default <- function(x, y,
         stop("All predictors must be numeric for this model") 
     }
 
-  # add the outcome to the data passed into the functions
+  ## Add the outcome to the data passed into the functions
   trainData$.outcome <- y
 
-  # if no default training grid is specified, get one. We have to pass in the formula
-  # and data for some models (rpart, pam, etc - see manual fo rmore details)
+  ## If no default training grid is specified, get one. We have to pass in the formula
+  ## and data for some models (rpart, pam, etc - see manual fo rmore details)
   if(is.null(tuneGrid)) tuneGrid <- createGrid(method, tuneLength, trainData)
 
-  #------------------------------------------------------------------------------------------------------------------------------------------------------#
+  ##------------------------------------------------------------------------------------------------------------------------------------------------------#
 
-  # For each tuning parameter combination, we will loop over them, fit models and generate predictions.
-  # We only save the predictions at this point, not the models (and in the case of method = "oob" we 
-  # only save the prediction summaries at this stage.
+  ## For each tuning parameter combination, we will loop over them, fit models and generate predictions.
+  ## We only save the predictions at this point, not the models (and in the case of method = "oob" we 
+  ## only save the prediction summaries at this stage.
   
-  # trainInfo will hold teh infomration about how we should loop to train the model and what types
-  # of parameters are used. If method = "oob", we need to setip a container for the resamplng 
-  # summary statistics 
+  ## trainInfo will hold teh infomration about how we should loop to train the model and what types
+  ## of parameters are used. If method = "oob", we need to setip a container for the resamplng 
+  ## summary statistics 
   
   trainInfo <- tuneScheme(method, tuneGrid, trControl$method == "oob")
   paramCols <- paste(".", trainInfo$model$parameter, sep = "")
-  
+
   if(trainInfo$scheme == "oob")
     {
+      ## For oob performance, we will make a container for the results
+      ## In other cases, it will be created on the fly after the predictions are made
       if(modelType == "Regression")
         {
           performance <- data.frame(matrix(NA, ncol = 4, nrow = dim(trainInfo$loop)[1]))   
-          names(performance) <- c("RMSE", "Rsquared", "RMSESD", "RsquaredSD")   
-          
+          names(performance) <- c("RMSE", "Rsquared", "RMSESD", "RsquaredSD")      
         } else {
           performance <- data.frame(matrix(NA, ncol = 4, nrow = dim(trainInfo$loop)[1]))   
           names(performance) <- c("Accuracy", "Kappa", "AccuracySD", "KappaSD")
         }
-    }   
+      perfNames <- c("Accuracy", "Kappa")
+    } else {
+      testOutput <- data.frame(pred = sample(y, min(10, length(y))),
+                               obs = sample(y, min(10, length(y))))
+      perfNames <- names(trControl$summaryFunction(testOutput,
+                                                   classLevels,
+                                                   method))
+    }
+
+  if(!(metric %in% perfNames))
+    {
+      oldMetric <- metric
+      metric <- perfNames[1]
+      warning(paste("The metric \"",
+                    oldMetric,
+                    "\" was not in ",
+                    "the result set. ",
+                    metric,
+                    " will be used instead.",
+                    sep = ""))
+    }
 
   results <- NULL
   for(j in 1:nrow(trainInfo$loop))
@@ -110,7 +132,7 @@ train.default <- function(x, y,
                       obsLevels = classLevels)
       argList <- append(argList, list(...))         
       
-      # use switch statement here instead
+      
       switch(
              trainInfo$scheme,
              basic = 
@@ -144,16 +166,20 @@ train.default <- function(x, y,
                
              })     
     }   
-
-
+ 
   paramNames <- substring(names(tuneGrid), 2)
   if(trControl$method != "oob")
     {     
-      perResample <- poolByResample(results, tuneGrid, foo)
-      performance <- summarize(perResample, tuneGrid, foo)
+      perResample <- poolByResample(results,
+                                    tuneGrid,
+                                    trControl$summaryFunction,
+                                    perfNames,
+                                    classLevels,
+                                    method)
+      performance <- summarize(perResample, tuneGrid)
 
-      # There are some cases where every resampled model
-      # failed for the tuning parameter(s). Catch these.
+      ## There are some cases where every resampled model
+      ## failed for the tuning parameter(s). Catch these.
       goodResults <- complete.cases(performance)
       if(any(!goodResults))
         {
@@ -174,28 +200,36 @@ train.default <- function(x, y,
   perfCols <- names(performance)
   perfCols <- perfCols[!(perfCols %in% paramNames)]
 
-  # sort the tuning parameters form least complex to most complex
+  ## Sort the tuning parameters form least complex to most complex
   performance <- byComplexity(performance, method)
 
-  # select the optimal set
+  ## select the optimal set
 
   selectClass <- class(trControl$selectionFunction)[1]
 
   if(selectClass == "function")
     {
-      bestIter <- trControl$selectionFunction(performance, metric)
+      bestIter <- trControl$selectionFunction(
+                                              x = performance,
+                                              metric = metric,
+                                              maximize = maximize)
     }
   else {
     if(trControl$selectionFunction == "oneSE")
       {
-        bestIter <- oneSE(performance, metric, length(trControl$index))
+        bestIter <- oneSE(
+                          performance,
+                          metric,
+                          length(trControl$index),
+                          maximize)
       } else {
 
         bestIter <- do.call(
                             trControl$selectionFunction,
                             list(
                                  x = performance,
-                                 metric = metric))
+                                 metric = metric,
+                                 maximize = maximize))
       }
   }
   
@@ -203,14 +237,27 @@ train.default <- function(x, y,
   names(bestTune) <- paste(".", names(bestTune), sep = "") 
   
   if(trControl$method != "oob")
-    {           
-      byResample <- merge(bestTune, perResample)        
-      byResample <- byResample[,!(names(perResample) %in% names(tuneGrid))]                     
+    {
+      
+      byResample <- switch(trControl$returnResamp,
+                           none = NULL,
+                           all =
+                           {
+                             out <- perResample
+                             colnames(out) <- gsub("^\\.", "", colnames(out))
+                             out
+                           },
+                           final =
+                           {
+                             out <- merge(bestTune, perResample)        
+                             out <- out[,!(names(perResample) %in% names(tuneGrid))]
+                             out
+                           })                        
     } else {
       byResample <- NULL        
     } 
 
-  # reorder rows of performance
+  ## $eorder rows of performance
   orderList <- list()
   for(i in seq(along = trainInfo$model$parameter))
     {
@@ -220,7 +267,7 @@ train.default <- function(x, y,
   performance <- performance[do.call("order", orderList),]      
   
   
-  #------------------------------------------------------------------------------------------------------------------------------------------------------#
+  ##------------------------------------------------------------------------------------------------------------------------------------------------------#
 
   finalModel <- createModel(
                             trainData, 
@@ -229,13 +276,13 @@ train.default <- function(x, y,
                             obsLevels = classLevels, 
                             ...)
   
-  # remove this and check for other places it is reference
-  # replaced by tuneValue
+  ## Remove this and check for other places it is reference
+  ## replaced by tuneValue
   if(method == "pls") finalModel$bestIter <- bestTune
   
   outData <- if(trControl$returnData) trainData else NULL
   
-  # in the case of pam, the data will need to be saved differently
+  ## In the case of pam, the data will need to be saved differently
   if(trControl$returnData & method == "pam")
     {
       finalModel$xData <- x
@@ -253,9 +300,33 @@ train.default <- function(x, y,
                  control = trControl,
                  finalModel = finalModel,
                  trainingData = outData,
-                 resample = byResample
+                 resample = byResample,
+                 perfNames = perfNames,
+                 maximize = maximize
                  ), 
             class = "train")
 }
 
-
+train.formula <- function (form, data, ..., subset, na.action, contrasts = NULL) 
+{
+  m <- match.call(expand.dots = FALSE)
+  if (is.matrix(eval.parent(m$data))) m$data <- as.data.frame(data)
+  m$... <- m$contrasts <- NULL
+  m[[1]] <- as.name("model.frame")
+  m <- eval.parent(m)
+  Terms <- attr(m, "terms")
+  x <- model.matrix(Terms, m, contrasts)
+  cons <- attr(x, "contrast")
+  xint <- match("(Intercept)", colnames(x), nomatch = 0)
+  if (xint > 0)  x <- x[, -xint, drop = FALSE]
+  y <- model.response(m)
+  res <- train(x, y, ...)
+  res$terms <- Terms
+  res$coefnames <- colnames(x)
+  res$call <- match.call()
+  res$na.action <- attr(m, "na.action")
+  res$contrasts <- cons
+  res$xlevels <- .getXlevels(Terms, m)
+  class(res) <- c("train", "train.formula")
+  res
+}
