@@ -3,17 +3,22 @@ trainControl <- function(
                          number = ifelse(method == "cv", 10, 25),
                          verboseIter = TRUE,
                          returnData = TRUE,
-                         p = .5,
+                         returnResamp = "final",
+                         p = .75,
+                         summaryFunction = defaultSummary,
                          selectionFunction = "best",
                          index = NULL)
 {
   if(is.null(selectionFunction)) stop("null selectionFunction values not allowed")
+  if(!(returnResamp %in% c("all", "final", "none"))) stop("incorrect value of returnResamp")
   list(
        method = method,
        number = number,
        verboseIter = verboseIter,
        returnData = returnData,
+       returnResamp = returnResamp,
        p = p,
+       summaryFunction = summaryFunction,
        selectionFunction = selectionFunction,
        index = index)
 }
